package dtgateway

import (
	"GtDataStore/app/cmd/dtgateway/internal/svc"
	"GtDataStore/app/cmd/dtgateway/internal/types"
	"GtDataStore/app/cmd/organization/pb"
	"GtDataStore/common/xerr"
	"context"

	"github.com/zeromicro/go-zero/core/logx"
)

type ItemHistoryDataListLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewItemHistoryDataListLogic(ctx context.Context, svcCtx *svc.ServiceContext) *ItemHistoryDataListLogic {
	return &ItemHistoryDataListLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

func (l *ItemHistoryDataListLogic) ItemHistoryDataList(req *types.ItemHistoryDataListReq) (resp *types.CommonResponse, err error) {
	dataList, err := l.svcCtx.OrganizationRpc.ItemHistoryDataForChart(l.ctx, &pb.ItemHistoryDataForChartReq{
		ProjectId:  req.ProjectId,
		ItemName:   req.ItemName,
		Interval:   req.Interval,
		Aggregator: req.Aggregator,
		Stime:      req.STime,
		Etime:      req.ETime,
		Size:       req.Size,
		Order:      req.Order,
		MaxVal:     req.MaxVal,
		MinVal:     req.MinVal,
	})
	if err != nil {
		return nil, err
	}
	return &types.CommonResponse{
		Code: xerr.OK,
		Msg:  xerr.MapErrMsg(xerr.OK),
		Data: dataList,
	}, nil
}
