package dtgateway

import (
	"GtDataStore/app/cmd/dtgateway/internal/svc"
	"GtDataStore/app/cmd/dtgateway/internal/types"
	"GtDataStore/app/cmd/organization/pb"
	"GtDataStore/common/xerr"
	"context"
	"errors"
	"github.com/zeromicro/go-zero/core/logx"
)

type ItemHistoryDataMultiAddLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewItemHistoryDataMultiAddLogic(ctx context.Context, svcCtx *svc.ServiceContext) *ItemHistoryDataMultiAddLogic {
	return &ItemHistoryDataMultiAddLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

func (l *ItemHistoryDataMultiAddLogic) ItemHistoryDataMultiAdd(req *types.MultiAddItemHistoryDataReq) (resp *types.CommonResponse, err error) {
	if len(req.List) == 0 {
		return nil, errors.New("data list is empty")
	}

	dataList := make([]*pb.ItemHistoryData, len(req.List))
	for i, line := range req.List {
		dataList[i] = &pb.ItemHistoryData{
			ProjectId: line.ProjectId,
			ItemName:  line.ItemName,
			Val:       line.Val,
			HTime:     line.HTime,
		}
	}
	_, err = l.svcCtx.OrganizationRpc.MultiAddItemHistoryData(l.ctx, &pb.MultiAddItemHistoryDataReq{
		ProjectId: req.List[0].ProjectId,
		List:      dataList,
	})
	if err != nil {
		return nil, err
	}

	return &types.CommonResponse{
		Code: xerr.OK,
		Msg:  xerr.MapErrMsg(xerr.OK),
		Data: nil,
	}, nil
}
