package logic

import (
	"GtDataStore/app/cmd/organization/internal/svc"
	"GtDataStore/app/cmd/organization/pb"
	"GtDataStore/app/model"
	"context"

	"github.com/zeromicro/go-zero/core/logx"
)

type GetWorkingPumpByCodeLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewGetWorkingPumpByCodeLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GetWorkingPumpByCodeLogic {
	return &GetWorkingPumpByCodeLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

func (l *GetWorkingPumpByCodeLogic) GetWorkingPumpByCode(in *pb.DcWorkingReq) (*pb.GetWorkingPumpByCodeResp, error) {
	offset := (in.Page - 1) * in.PageSize
	res, err := l.svcCtx.WorkingPump.Search(l.ctx, in.ProjectId, in.DeviceCode, in.Stime, in.Etime, offset, in.PageSize, in.Order)
	if err != nil && err != model.ErrNotFound {
		return nil, err
	}

	list := make([]*pb.WorkingPump, len(res))
	for i, one := range res {
		list[i] = &pb.WorkingPump{
			Id:           one.Id,
			ProjectId:    one.ProjectId,
			DeviceCode:   one.DeviceCode,
			FeedPressure: one.FeedPressure,
			OutPressure:  one.OutPressure,
			Duration:     one.Duration,
			Current:      one.Current,
			Frequency:    one.Frequency,
			Lift:         one.Lift,
			Efficiency:   one.Efficiency,
			RunStatus:    one.RunStatus,
			FaultStatus:  one.FaultStatus,
			CTime:        one.CTime.Format("2006-01-02 15:04:05"),
		}
	}

	return &pb.GetWorkingPumpByCodeResp{
		List: list,
	}, nil
}
