package main

import (
	"GtDataStore/app/cmd/organization/internal/config"
	"GtDataStore/app/cmd/organization/internal/logic/handler"
	"GtDataStore/app/cmd/organization/internal/logic/job"
	"GtDataStore/app/cmd/organization/internal/server"
	"GtDataStore/app/cmd/organization/pb"
	"github.com/go-redis/redis/v8"
	"github.com/zeromicro/go-zero/core/service"
	"github.com/zeromicro/go-zero/zrpc"
	"google.golang.org/grpc"
	"google.golang.org/grpc/reflection"
	"metawant.greentech.com.cn/gaoyagang/gt-common/envitem"

	//"GtDataStore/app/cmd/organization/internal/server"
	"GtDataStore/app/cmd/organization/internal/svc"

	"flag"
	"fmt"

	"github.com/zeromicro/go-zero/core/conf"
	//"github.com/zeromicro/go-zero/core/service"
	//"github.com/zeromicro/go-zero/zrpc"
	//"google.golang.org/grpc"
	//"google.golang.org/grpc/reflection"
)

var configFile = flag.String("f", "etc/organization.yaml", "the config file")

func main() {
	flag.Parse()

	var c config.Config
	conf.MustLoad(*configFile, &c)
	ctx := svc.NewServiceContext(c)

	s := zrpc.MustNewServer(c.RpcServerConf, func(grpcServer *grpc.Server) {
		pb.RegisterOrganizationServer(grpcServer, server.NewOrganizationServer(ctx))

		if c.Mode == service.DevMode || c.Mode == service.TestMode {
			reflection.Register(grpcServer)
		}
	})
	defer s.Stop()

	if c.Mode == "pro" {
		envitem.SetOptions(envitem.Options{GtServerIp: c.GtServerIp, AdjustValue: true, Cache: redis.NewClient(&redis.Options{Addr: c.Cache[0].Host, Password: c.Cache[0].Pass, MaxRetries: 5})})

		go func() {
			defer func() {
				fmt.Print("async organization job stop.....\n")
			}()
			j := job.NewJob(1, "organization-"+c.Mode, ctx, handler.DeviceHandlerTable, handler.DeviceIntervalTable)
			j.Run()
		}()
	}

	fmt.Printf("Starting rpc server at %s...\n", c.ListenOn)
	s.Start()
}
